<?php

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Kupindo_Feed
 * @subpackage Kupindo_Feed/includes
 * @author     Smdesign Studio <podrska@smdesign.rs>
 */
class Kupindo_Feed
{

    /**
     * The loader that's responsible for maintaining and registering all hooks that power
     * the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      Kupindo_Feed_Loader $loader Maintains and registers all hooks for the plugin.
     */
    protected $loader;

    /**
     * The unique identifier of this plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string $kupindo_feed The string used to uniquely identify this plugin.
     */
    protected $kupindo_feed;

    /**
     * The current version of the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string $version The current version of the plugin.
     */
    protected $version;

    /**
     * Define the core functionality of the plugin.
     *
     * Set the plugin name and the plugin version that can be used throughout the plugin.
     * Load the dependencies, define the locale, and set the hooks for the admin area and
     * the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function __construct()
    {
        $this->kupindo_feed = 'kupindo-feed';
        $this->version = '1.0.1';
        
        $this->load_dependencies();
        $this->set_locale();
        $this->define_admin_hooks();
        $this->define_public_hooks();
    }



    /**
     * Load the required dependencies for this plugin.
     *
     * Include the following files that make up the plugin:
     *
     * - Kupindo_Feed_Loader. Orchestrates the hooks of the plugin.
     * - Kupindo_Feed_i18n. Defines internationalization functionality.
     * - Kupindo_Feed_Admin. Defines all hooks for the admin area.
     * - Kupindo_Feed_Public. Defines all hooks for the public side of the site.
     *
     * Create an instance of the loader which will be used to register the hooks
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */
    private function load_dependencies()
    {

        /**
         * The class responsible for orchestrating the actions and filters of the
         * core plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-kupindo-feed-loader.php';

        /**
         * The class responsible for defining internationalization functionality
         * of the plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-kupindo-feed-i18n.php';

        /**
         * The class responsible for getting all product information
         * of the plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/classes/class-kupindo-feed-products.php';
        /**
         * The class responsible for processing feed
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/classes/class-kupindo-feed-engine.php';

        /**
         * The class contain all merchants attribute dropdown
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/classes/class-kupindo-feed-dropdown.php';

        /**
         * The class contain merchant attributes
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/classes/class-kupindo-feed-default-attributes.php';

        /**
         * The class responsible for generating feed
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/feeds/class-kupindo-feed-generate.php';

        /**
         * The class is a FTP library
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/classes/class-kupindo-feed-ftp.php';
        
        /**
         * The class 
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/classes/class-kupindo-feed-auto-update.php';


        /**
         * The class responsible for save feed
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/classes/class-kupindo-feed-savefile.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/classes/class-kupindo-feed-admin-message.php';
        /**
         * Merchant classes
         */
        require plugin_dir_path(dirname(__FILE__)) . 'includes/feeds/class-kupindo-feed-kupindo.php';
        require plugin_dir_path(dirname(__FILE__)) . 'includes/feeds/class-kupindo-feed-custom.php';

        /**
         * The class responsible for defining all actions that occur in the admin area.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-kupindo-feed-admin.php';

        /**
         * The class responsible for defining all actions that occur in the public area.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'public/class-kupindo-feed-public.php';
        
        /**
         * The class responsible for making list table
         */

        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/classes/class-kupindo-feed-list-table.php';


        /**
         * The class responsible for making feed list
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-kupindo-feed-manage-list.php';

        $this->loader = new Kupindo_Feed_Loader();

    }

    /**
     * Define the locale for this plugin for internationalization.
     *
     * Uses the Kupindo_Feed_i18n class in order to set the domain and to register the hook
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */
    private function set_locale()
    {

        $plugin_i18n = new Kupindo_Feed_i18n();
        $plugin_i18n->set_domain($this->get_kupindo_feed());

        $this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');

    }

    /**
     * Register all of the hooks related to the admin area functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */
    private function define_admin_hooks()
    {

        $plugin_admin = new Kupindo_Feed_Admin($this->get_kupindo_feed(), $this->get_version());

        $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
        $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');
        $this->loader->add_action('admin_menu', $plugin_admin, 'load_admin_pages');

    }

    /**
     * Register all of the hooks related to the public-facing functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */
    private function define_public_hooks() {

        $plugin_public = new Kupindo_Feed_Public( $this->get_kupindo_feed(), $this->get_version() );

        $this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
        $this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

    }

    /**
     * Run the loader to execute all of the hooks with WordPress.
     *
     * @since    1.0.0
     */
    public function run()
    {
        $this->loader->run();
    }

    /**
     * The name of the plugin used to uniquely identify it within the context of
     * WordPress and to define internationalization functionality.
     *
     * @since     1.0.0
     * @return    string    The name of the plugin.
     */
    public function get_kupindo_feed()
    {
        return $this->kupindo_feed;
    }

    /**
     * The reference to the class that orchestrates the hooks with the plugin.
     *
     * @since     1.0.0
     * @return    Kupindo_Feed_Loader    Orchestrates the hooks of the plugin.
     */
    public function get_loader()
    {
        return $this->loader;
    }

    /**
     * Retrieve the version number of the plugin.
     *
     * @since     1.0.0
     * @return    string    The version number of the plugin.
     */
    public function get_version()
    {
        return $this->version;
    }

}


